==> bluer_ai-12.4.1-py3-none-any.whl: bluer_ai/.abcli/tests/string.sh <==
#! /usr/bin/env bash

function abcli_string_after() {
    abcli_assert \
        $(abcli_string_after \
            "this-is-a-test" \
            "") \
        ""
    abcli_assert \
        $(abcli_string_after \
            "this-is-a-test" \
            "was") \
        ""

    abcli_assert \
        $(abcli_string_after \
            "this-is-a-test" \
            "is") \
        "-is-a-test"

    abcli_assert \
        $(abcli_string_after \
            "this-is-a-test-that-is-very-important" \
            "is") \
        "-is-a-test-that-is-very-important"

    abcli_assert \
        $(abcli_string_after \
            "this-is-a-test-that-is-very-important-and-now-is-running" \
            "is") \
        "-is-a-test-that-is-very-important-and-now-is-running"
}

function abcli_string_before() {
    abcli_assert \
        $(abcli_string_before \
            "this-is-a-test" \
            "") \
        ""
    abcli_assert \
        $(abcli_string_before \
            "this-is-a-test" \
            "was") \
        ""

    abcli_assert \
        $(abcli_string_before \
            "this-is-a-test" \
            "is") \
        "th"

    abcli_assert \
        $(abcli_string_before \
            "this-is-a-test-that-is-very-important" \
            "is") \
        "th"

    abcli_assert \
        $(abcli_string_before \
            "this-is-a-test-that-is-very-important-and-now-is-running" \
            "is") \
        "th"
}

function test_bluer_ai_string_random() {
    abcli_assert \
        $(abcli_string_random) \
        - non-empty
}

function test_bluer_ai_string_timestamp() {
    abcli_assert \
        $(abcli_string_timestamp) \
        - non-empty
}

function test_bluer_ai_string_timestamp_short() {
    abcli_assert \
        $(abcli_string_timestamp_short) \
        - non-empty
}

function test_bluer_ai_string_today() {
    abcli_assert \
        $(abcli_string_today) \
        - non-empty
}

==> bluer_ai-12.73.1-py3-none-any.whl: bluer_ai/.abcli/tests/string.sh <==
#! /usr/bin/env bash

function test_bluer_ai_string_after() {
    bluer_ai_assert \
        $(abcli_string_after \
            "this-is-a-test" \
            "") \
        ""
    [[ $? -ne 0 ]] && return 1

    bluer_ai_assert \
        $(abcli_string_after \
            "this-is-a-test" \
            "was") \
        ""
    [[ $? -ne 0 ]] && return 1

    bluer_ai_assert \
        $(abcli_string_after \
            "this-is-a-test" \
            "is") \
        "-is-a-test"
    [[ $? -ne 0 ]] && return 1

    bluer_ai_assert \
        $(abcli_string_after \
            "this-is-a-test-that-is-very-important" \
            "is") \
        "-is-a-test-that-is-very-important"
    [[ $? -ne 0 ]] && return 1

    bluer_ai_assert \
        $(abcli_string_after \
            "this-is-a-test-that-is-very-important-and-now-is-running" \
            "is") \
        "-is-a-test-that-is-very-important-and-now-is-running"
}

function test_bluer_ai_string_before() {
    bluer_ai_assert \
        $(abcli_string_before \
            "this-is-a-test" \
            "") \
        ""
    [[ $? -ne 0 ]] && return 1

    bluer_ai_assert \
        $(abcli_string_before \
            "this-is-a-test" \
            "was") \
        ""
    [[ $? -ne 0 ]] && return 1

    bluer_ai_assert \
        $(abcli_string_before \
            "this-is-a-test" \
            "is") \
        "th"
    [[ $? -ne 0 ]] && return 1

    bluer_ai_assert \
        $(abcli_string_before \
            "this-is-a-test-that-is-very-important" \
            "is") \
        "th"
    [[ $? -ne 0 ]] && return 1

    bluer_ai_assert \
        $(abcli_string_before \
            "this-is-a-test-that-is-very-important-and-now-is-running" \
            "is") \
        "th"
}

function test_bluer_ai_string_random() {
    bluer_ai_assert \
        $(abcli_string_random) \
        - non-empty
}

function test_bluer_ai_string_timestamp() {
    bluer_ai_assert \
        $(abcli_string_timestamp) \
        - non-empty
}

function test_bluer_ai_string_timestamp_short() {
    bluer_ai_assert \
        $(abcli_string_timestamp_short) \
        - non-empty
}

function test_bluer_ai_string_today() {
    bluer_ai_assert \
        $(abcli_string_today) \
        - non-empty
}
